# Copyright (C) 2021 Associated Universities, Inc. Washington DC, USA.
#
# This file is part of NRAO Workspaces.
#
# Workspaces is free software: you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# Workspaces is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with Workspaces.  If not, see <https://www.gnu.org/licenses/>.
"""add DAs and AODs to db

Revision ID: 53b0c9f115f8
Revises: 702a4a776f9b
Create Date: 2022-01-24 13:05:18.476190

"""
import sqlalchemy as sa
from alembic import op

# revision identifiers, used by Alembic.
revision = "53b0c9f115f8"
down_revision = "702a4a776f9b"
branch_labels = None
depends_on = None


def upgrade():
    op.create_table(
        "qa_staff",
        sa.Column(
            "user_name",
            sa.String,
            primary_key=True,
            comment="The user name of the staff member performing QA.",
        ),
        sa.Column(
            "group",
            sa.String,
            comment="Is this staff member a DA or an AOD?",
        ),
        sa.Column(
            "available",
            sa.Boolean,
            default=True,
            comment="Is this staff member available to be assigned QA jobs?",
        ),
        comment="List of people capable of performing QA and their availability",
    )

    op.execute(
        """
        ALTER TABLE capability_requests
        ADD COLUMN assigned_da varchar 
        """
    )

    op.execute(
        """
        ALTER TABLE capability_requests
        ADD COLUMN assigned_aod varchar
        """
    )


def downgrade():
    op.drop_table("qa_staff")
    op.execute(
        """
        ALTER TABLE capability_requests DROP COLUMN IF EXISTS assigned_da
        """
    )
    op.execute(
        """
        ALTER TABLE capability_requests DROP COLUMN IF EXISTS assigned_aod
        """
    )
